@@ -1,13 +1,12 @@
 package Poet::Script;
 BEGIN {
-  $Poet::Script::VERSION = '0.11';
+  $Poet::Script::VERSION = '0.12';
 }
 use Cwd qw(realpath);
-use File::Basename;
 use File::Spec::Functions qw(rel2abs);
 use Method::Signatures::Simple;
 use Poet::Environment;
-use Poet::Tools qw(can_load read_file);
+use Poet::Tools qw(can_load dirname read_file);
 use strict;
 use warnings;
 
